ete2.parser

Package ete2 :: Package parser |
[hide private]
[frames] | no frames]

# Source Code for Package ete2.parser

     1  __VERSION__="ete2-2.0rev90"
     2  # #START_LICENSE###########################################################
     3  #
     4  # Copyright (C) 2009 by Jaime Huerta Cepas. All rights reserved.
     5  # email: jhcepas@gmail.com
     6  #
     7  # This file is part of the Environment for Tree Exploration program (ETE).
     8  # http://ete.cgenomics.org
     9  #
    10  # ETE is free software: you can redistribute it and/or modify it
    11  # under the terms of the GNU General Public License as published by
    12  # the Free Software Foundation, either version 3 of the License, or
    13  # (at your option) any later version.
    14  #
    15  # ETE is distributed in the hope that it will be useful,
    16  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    17  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    18  # GNU General Public License for more details.
    19  #
    20  # You should have received a copy of the GNU General Public License
    21  # along with ETE.  If not, see <http://www.gnu.org/licenses/>.
    22  #
    23  # #END_LICENSE#############################################################
    24